@@ -116,7 +116,7 @@ def test_resultlog_is_deprecated(testdir):
     result.stdout.fnmatch_lines(
         [
             "*--result-log is deprecated and scheduled for removal in pytest 4.0*",
-            "*See https://docs.pytest.org/*/usage.html#creating-resultlog-format-files for more information*",
+            "*See https://docs.pytest.org/en/latest/usage.html#creating-resultlog-format-files for more information*",
         ]
     )
 
