@@ -559,6 +559,19 @@ class TestLastFailed(object):
         testdir.runpytest("-q", "--lf")
         assert os.path.exists(".pytest_cache/v/cache/lastfailed")
 
+    @pytest.mark.parametrize("quiet", [True, False])
+    @pytest.mark.parametrize("opt", ["--ff", "--lf"])
+    def test_lf_and_ff_obey_verbosity(self, quiet, opt, testdir):
+        testdir.makepyfile("def test(): pass")
+        args = [opt]
+        if quiet:
+            args.append("-q")
+        result = testdir.runpytest(*args)
+        if quiet:
+            assert "run all" not in result.stdout.str()
+        else:
+            assert "run all" in result.stdout.str()
+
     def test_xfail_not_considered_failure(self, testdir):
         testdir.makepyfile(
             """
